# `royalnet.herald`

The subpackage providing all functions and classes to handle communication between process (even over the Internet).

It is based on [`websockets`](https://github.com/websockets).

It requires the `herald` extra to be installed.

You can install it with:
```
pip install royalnet[herald]
```
